@@ -1,5 +1,6 @@
 from .credentials import *  # noqa
 from .driver import *  # noqa
+from .global_settings import *  # noqa
 from .table import *  # noqa
 from .issues import *  # noqa
 from .types import *  # noqa
@@ -12,6 +13,7 @@ from .operation import *  # noqa
 from .scripting import *  # noqa
 from .import_client import *  # noqa
 from .tracing import *  # noqa
+from .topic import *  # noqa
 
 try:
     import ydb.aio as aio  # noqa
