@@ -1,20 +1,45 @@
 # -*- coding: utf-8 -*-
-from ydb._grpc.common import (
-    ydb_cms_v1_pb2_grpc,
-    ydb_discovery_v1_pb2_grpc,
-    ydb_scheme_v1_pb2_grpc,
-    ydb_table_v1_pb2_grpc,
-)
-from ydb._grpc.common.protos import (
-    ydb_status_codes_pb2,
-    ydb_discovery_pb2,
-    ydb_scheme_pb2,
-    ydb_table_pb2,
-    ydb_value_pb2,
-)
-from ydb._grpc.common.protos import ydb_operation_pb2
-from ydb._grpc.common.protos import ydb_common_pb2
-from ydb._grpc.common import ydb_operation_v1_pb2_grpc
+import typing
+
+# Workaround for good IDE and universal for runtime
+if typing.TYPE_CHECKING:
+    from ._grpc.v4 import (
+        ydb_cms_v1_pb2_grpc,
+        ydb_discovery_v1_pb2_grpc,
+        ydb_scheme_v1_pb2_grpc,
+        ydb_table_v1_pb2_grpc,
+        ydb_operation_v1_pb2_grpc,
+        ydb_topic_v1_pb2_grpc,
+    )
+
+    from ._grpc.v4.protos import (
+        ydb_status_codes_pb2,
+        ydb_discovery_pb2,
+        ydb_scheme_pb2,
+        ydb_table_pb2,
+        ydb_value_pb2,
+        ydb_operation_pb2,
+        ydb_common_pb2,
+    )
+else:
+    from ._grpc.common import (
+        ydb_cms_v1_pb2_grpc,
+        ydb_discovery_v1_pb2_grpc,
+        ydb_scheme_v1_pb2_grpc,
+        ydb_table_v1_pb2_grpc,
+        ydb_operation_v1_pb2_grpc,
+        ydb_topic_v1_pb2_grpc,
+    )
+
+    from ._grpc.common.protos import (
+        ydb_status_codes_pb2,
+        ydb_discovery_pb2,
+        ydb_scheme_pb2,
+        ydb_table_pb2,
+        ydb_value_pb2,
+        ydb_operation_pb2,
+        ydb_common_pb2,
+    )
 
 
 StatusIds = ydb_status_codes_pb2.StatusIds
@@ -74,3 +99,13 @@ class TableService(object):
     KeepAlive = "KeepAlive"
     StreamReadTable = "StreamReadTable"
     BulkUpsert = "BulkUpsert"
+
+
+class TopicService(object):
+    Stub = ydb_topic_v1_pb2_grpc.TopicServiceStub
+
+    CreateTopic = "CreateTopic"
+    DescribeTopic = "DescribeTopic"
+    DropTopic = "DropTopic"
+    StreamRead = "StreamRead"
+    StreamWrite = "StreamWrite"
