@@ -1,10 +1,11 @@
 # -*- coding: utf-8 -*-
-import six
+import threading
 import codecs
 from concurrent import futures
 import functools
 import hashlib
 import collections
+import urllib.parse
 from . import ydb_version
 
 try:
@@ -55,8 +56,8 @@ def parse_connection_string(connection_string):
         # default is grpcs
         cs = _grpcs_protocol + cs
 
-    p = six.moves.urllib.parse.urlparse(connection_string)
-    b = six.moves.urllib.parse.parse_qs(p.query)
+    p = urllib.parse.urlparse(connection_string)
+    b = urllib.parse.parse_qs(p.query)
     database = b.get("database", [])
     assert len(database) > 0
 
@@ -77,11 +78,9 @@ def wrap_async_call_exceptions(f):
 
 def get_query_hash(yql_text):
     try:
-        return hashlib.sha256(
-            six.text_type(yql_text, "utf-8").encode("utf-8")
-        ).hexdigest()
+        return hashlib.sha256(str(yql_text, "utf-8").encode("utf-8")).hexdigest()
     except TypeError:
-        return hashlib.sha256(six.text_type(yql_text).encode("utf-8")).hexdigest()
+        return hashlib.sha256(str(yql_text).encode("utf-8")).hexdigest()
 
 
 class LRUCache(object):
@@ -159,3 +158,17 @@ class SyncResponseIterator(object):
 
     def __next__(self):
         return self._next()
+
+
+class AtomicCounter:
+    _lock: threading.Lock
+    _value: int
+
+    def __init__(self, initial_value: int = 0):
+        self._lock = threading.Lock()
+        self._value = initial_value
+
+    def inc_and_get(self) -> int:
+        with self._lock:
+            self._value += 1
+            return self._value
