@@ -1,5 +1,6 @@
 import logging
 import asyncio
+import typing
 from typing import Any, Tuple, Callable, Iterable
 import collections
 import grpc
@@ -24,11 +25,19 @@ from ydb.driver import DriverConfig
 from ydb.settings import BaseRequestSettings
 from ydb import issues
 
+# Workaround for good IDE and universal for runtime
+if typing.TYPE_CHECKING:
+    from ydb._grpc.v4 import ydb_topic_v1_pb2_grpc
+else:
+    from ydb._grpc.common import ydb_topic_v1_pb2_grpc
+
+
 _stubs_list = (
     _apis.TableService.Stub,
     _apis.SchemeService.Stub,
     _apis.DiscoveryService.Stub,
     _apis.CmsService.Stub,
+    ydb_topic_v1_pb2_grpc.TopicServiceStub,
 )
 logger = logging.getLogger(__name__)
 
@@ -118,13 +127,9 @@ class Connection:
     ):
         global _stubs_list
         self.endpoint = endpoint
-        self.endpoint_key = EndpointKey(
-            self.endpoint, getattr(endpoint_options, "node_id", None)
-        )
+        self.endpoint_key = EndpointKey(self.endpoint, getattr(endpoint_options, "node_id", None))
         self.node_id = getattr(endpoint_options, "node_id", None)
-        self._channel = channel_factory(
-            self.endpoint, driver_config, grpc.aio, endpoint_options=endpoint_options
-        )
+        self._channel = channel_factory(self.endpoint, driver_config, grpc.aio, endpoint_options=endpoint_options)
         self._driver_config = driver_config
 
         self._stub_instances = {}
@@ -143,14 +148,10 @@ class Connection:
         self, stub: Any, rpc_name: str, request: Any, settings: BaseRequestSettings
     ) -> Tuple[_RpcState, float, Any]:
 
-        timeout, metadata = _get_request_timeout(settings), await _construct_metadata(
-            self._driver_config, settings
-        )
+        timeout, metadata = _get_request_timeout(settings), await _construct_metadata(self._driver_config, settings)
         _set_server_timeouts(request, settings, timeout)
         self._prepare_stub_instance(stub)
-        rpc_state = _RpcState(
-            self._stub_instances[stub], rpc_name, self.endpoint, self.endpoint_key
-        )
+        rpc_state = _RpcState(self._stub_instances[stub], rpc_name, self.endpoint, self.endpoint_key)
         logger.debug("%s: creating call state", rpc_state)
 
         if self.closing:
@@ -182,24 +183,16 @@ class Connection:
         :param wrap_args: And arguments to be passed into wrap_result callable
         :return: A result of computation
         """
-        rpc_state, timeout, metadata = await self._prepare_call(
-            stub, rpc_name, request, settings
-        )
+        rpc_state, timeout, metadata = await self._prepare_call(stub, rpc_name, request, settings)
         try:
-            feature = asyncio.ensure_future(
-                rpc_state(request, timeout=timeout, metadata=metadata)
-            )
+            feature = asyncio.ensure_future(rpc_state(request, timeout=timeout, metadata=metadata))
 
             # Add feature to dict to wait until it finished when close called
             self.calls[rpc_state.request_id] = feature
 
             response = await feature
             _log_response(rpc_state, response)
-            return (
-                response
-                if wrap_result is None
-                else wrap_result(rpc_state, response, *wrap_args)
-            )
+            return response if wrap_result is None else wrap_result(rpc_state, response, *wrap_args)
         except grpc.RpcError as rpc_error:
             if on_disconnected:
                 coro = on_disconnected()
