@@ -3,7 +3,6 @@ import time
 import abc
 import asyncio
 import logging
-import six
 from ydb import issues, credentials
 
 logger = logging.getLogger(__name__)
@@ -55,7 +54,6 @@ class _AtMostOneExecution(object):
             asyncio.ensure_future(self._wrapped_execution(callback))
 
 
-@six.add_metaclass(abc.ABCMeta)
 class AbstractExpiringTokenCredentials(credentials.AbstractExpiringTokenCredentials):
     def __init__(self):
         super(AbstractExpiringTokenCredentials, self).__init__()
@@ -104,8 +102,7 @@ class AbstractExpiringTokenCredentials(credentials.AbstractExpiringTokenCredenti
                     )
                 )
             raise issues.ConnectionError(
-                "%s: %s.\n%s"
-                % (self.__class__.__name__, self.last_error, self.extra_error_message)
+                "%s: %s.\n%s" % (self.__class__.__name__, self.last_error, self.extra_error_message)
             )
         return cached_token
 
