@@ -3,7 +3,6 @@ import time
 
 import abc
 import logging
-import six
 from ydb.iam import auth
 from .credentials import AbstractExpiringTokenCredentials
 
@@ -24,20 +23,13 @@ except ImportError:
     aiohttp = None
 
 
-@six.add_metaclass(abc.ABCMeta)
 class TokenServiceCredentials(AbstractExpiringTokenCredentials):
     def __init__(self, iam_endpoint=None, iam_channel_credentials=None):
         super(TokenServiceCredentials, self).__init__()
-        assert (
-            iam_token_service_pb2_grpc is not None
-        ), "run pip install==ydb[yc] to use service account credentials"
+        assert iam_token_service_pb2_grpc is not None, "run pip install==ydb[yc] to use service account credentials"
         self._get_token_request_timeout = 10
-        self._iam_endpoint = (
-            "iam.api.cloud.yandex.net:443" if iam_endpoint is None else iam_endpoint
-        )
-        self._iam_channel_credentials = (
-            {} if iam_channel_credentials is None else iam_channel_credentials
-        )
+        self._iam_endpoint = "iam.api.cloud.yandex.net:443" if iam_endpoint is None else iam_endpoint
+        self._iam_channel_credentials = {} if iam_channel_credentials is None else iam_channel_credentials
 
     def _channel_factory(self):
         return grpc.aio.secure_channel(
@@ -52,9 +44,7 @@ class TokenServiceCredentials(AbstractExpiringTokenCredentials):
     async def _make_token_request(self):
         async with self._channel_factory() as channel:
             stub = iam_token_service_pb2_grpc.IamTokenServiceStub(channel)
-            response = await stub.Create(
-                self._get_token_request(), timeout=self._get_token_request_timeout
-            )
+            response = await stub.Create(self._get_token_request(), timeout=self._get_token_request_timeout)
             self.logger.debug(str(response))
             expires_in = max(0, response.expires_at.seconds - int(time.time()))
             return {"access_token": response.iam_token, "expires_in": expires_in}
@@ -96,9 +86,7 @@ class YandexPassportOAuthIamCredentials(TokenServiceCredentials):
         iam_channel_credentials=None,
     ):
         self._yandex_passport_oauth_token = yandex_passport_oauth_token
-        super(YandexPassportOAuthIamCredentials, self).__init__(
-            iam_endpoint, iam_channel_credentials
-        )
+        super(YandexPassportOAuthIamCredentials, self).__init__(iam_endpoint, iam_channel_credentials)
 
     def _get_token_request(self):
         return iam_token_service_pb2.CreateIamTokenRequest(
@@ -109,26 +97,17 @@ class YandexPassportOAuthIamCredentials(TokenServiceCredentials):
 class MetadataUrlCredentials(AbstractExpiringTokenCredentials):
     def __init__(self, metadata_url=None):
         super(MetadataUrlCredentials, self).__init__()
-        assert (
-            aiohttp is not None
-        ), "Install aiohttp library to use metadata credentials provider"
-        self._metadata_url = (
-            auth.DEFAULT_METADATA_URL if metadata_url is None else metadata_url
-        )
+        assert aiohttp is not None, "Install aiohttp library to use metadata credentials provider"
+        self._metadata_url = auth.DEFAULT_METADATA_URL if metadata_url is None else metadata_url
         self._tp.submit(self._refresh)
         self.extra_error_message = "Check that metadata service configured properly and application deployed in VM or function at Yandex.Cloud."
 
     async def _make_token_request(self):
         timeout = aiohttp.ClientTimeout(total=2)
         async with aiohttp.ClientSession(timeout=timeout) as session:
-            async with session.get(
-                self._metadata_url, headers={"Metadata-Flavor": "Google"}
-            ) as response:
+            async with session.get(self._metadata_url, headers={"Metadata-Flavor": "Google"}) as response:
                 if not response.ok:
-                    self.logger.error(
-                        "Error while getting token from metadata: %s"
-                        % await response.text()
-                    )
+                    self.logger.error("Error while getting token from metadata: %s" % await response.text())
                 response.raise_for_status()
                 # response from default metadata credentials provider
                 # contains text/plain content type.
