@@ -1,29 +1,34 @@
 # -*- coding: utf-8 -*-
 import abc
-import six
+import typing
+
 from . import tracing, issues, connection
 from . import settings as settings_impl
 import threading
 from concurrent import futures
 import logging
 import time
-from ydb._grpc.common.protos import ydb_auth_pb2
-from ydb._grpc.common import ydb_auth_v1_pb2_grpc
+
+# Workaround for good IDE and universal for runtime
+if typing.TYPE_CHECKING:
+    from ._grpc.v4.protos import ydb_auth_pb2
+    from ._grpc.v4 import ydb_auth_v1_pb2_grpc
+else:
+    from ._grpc.common.protos import ydb_auth_pb2
+    from ._grpc.common import ydb_auth_v1_pb2_grpc
 
 
 YDB_AUTH_TICKET_HEADER = "x-ydb-auth-ticket"
 logger = logging.getLogger(__name__)
 
 
-@six.add_metaclass(abc.ABCMeta)
-class AbstractCredentials(object):
+class AbstractCredentials(abc.ABC):
     """
     An abstract class that provides auth metadata
     """
 
 
-@six.add_metaclass(abc.ABCMeta)
-class Credentials(object):
+class Credentials(abc.ABC):
     def __init__(self, tracer=None):
         self.tracer = tracer if tracer is not None else tracing.Tracer(None)
 
@@ -34,6 +39,12 @@ class Credentials(object):
         """
         pass
 
+    def get_auth_token(self) -> str:
+        for header, token in self.auth_metadata():
+            if header == YDB_AUTH_TICKET_HEADER:
+                return token
+        return ""
+
 
 class OneToManyValue(object):
     def __init__(self):
@@ -80,7 +91,6 @@ class AtMostOneExecution(object):
             self._can_schedule = True
 
 
-@six.add_metaclass(abc.ABCMeta)
 class AbstractExpiringTokenCredentials(Credentials):
     def __init__(self, tracer=None):
         super(AbstractExpiringTokenCredentials, self).__init__(tracer)
@@ -114,12 +124,8 @@ class AbstractExpiringTokenCredentials(Credentials):
             )
 
     def _update_expiration_info(self, auth_metadata):
-        self._expires_in = time.time() + min(
-            self._hour, auth_metadata["expires_in"] / 2
-        )
-        self._refresh_in = time.time() + min(
-            self._hour / 2, auth_metadata["expires_in"] / 4
-        )
+        self._expires_in = time.time() + min(self._hour, auth_metadata["expires_in"] / 2)
+        self._refresh_in = time.time() + min(self._hour / 2, auth_metadata["expires_in"] / 4)
 
     def _refresh(self):
         current_time = time.time()
@@ -161,8 +167,7 @@ class AbstractExpiringTokenCredentials(Credentials):
                     )
                 )
             raise issues.ConnectionError(
-                "%s: %s.\n%s"
-                % (self.__class__.__name__, self.last_error, self.extra_error_message)
+                "%s: %s.\n%s" % (self.__class__.__name__, self.last_error, self.extra_error_message)
             )
         return cached_token
 
@@ -186,21 +191,15 @@ class StaticCredentials(AbstractExpiringTokenCredentials):
         self.request_timeout = 10
 
     def _make_token_request(self):
-        conn = connection.Connection.ready_factory(
-            self.driver_config.endpoint, self.driver_config
-        )
-        assert conn is not None, (
-            "Failed to establish connection in to %s" % self.driver_config.endpoint
-        )
+        conn = connection.Connection.ready_factory(self.driver_config.endpoint, self.driver_config)
+        assert conn is not None, "Failed to establish connection in to %s" % self.driver_config.endpoint
         try:
             result = conn(
                 ydb_auth_pb2.LoginRequest(user=self.user, password=self.password),
                 ydb_auth_v1_pb2_grpc.AuthServiceStub,
                 "Login",
                 _wrap_static_credentials_response,
-                settings_impl.BaseRequestSettings()
-                .with_timeout(self.request_timeout)
-                .with_need_rpc_auth(False),
+                settings_impl.BaseRequestSettings().with_timeout(self.request_timeout).with_need_rpc_auth(False),
             )
         finally:
             conn.close()
