@@ -1,7 +1,6 @@
 # -*- coding: utf-8 -*-
 import abc
 import enum
-import six
 import json
 from . import _utilities, _apis
 from datetime import date, datetime, timedelta
@@ -12,40 +11,30 @@ from google.protobuf import struct_pb2
 
 _SECONDS_IN_DAY = 60 * 60 * 24
 _EPOCH = datetime(1970, 1, 1)
-if six.PY3:
-    _from_bytes = None
-else:
-
-    def _from_bytes(x, table_client_settings):
-        return _utilities.from_bytes(x)
 
 
-def _from_date_number(x, table_client_settings):
-    if (
-        table_client_settings is not None
-        and table_client_settings._native_date_in_result_sets
-    ):
-        return date.fromordinal(x + date(1970, 1, 1).toordinal())
-    return x
+def _from_date(x, table_client_settings):
+    if table_client_settings is not None and table_client_settings._native_date_in_result_sets:
+        return _EPOCH.date() + timedelta(days=x.uint32_value)
+    return x.uint32_value
+
+
+def _to_date(pb, value):
+    if isinstance(value, date):
+        pb.uint32_value = (value - _EPOCH.date()).days
+    else:
+        pb.uint32_value = value
 
 
 def _from_datetime_number(x, table_client_settings):
-    if (
-        table_client_settings is not None
-        and table_client_settings._native_datetime_in_result_sets
-    ):
+    if table_client_settings is not None and table_client_settings._native_datetime_in_result_sets:
         return datetime.utcfromtimestamp(x)
     return x
 
 
 def _from_json(x, table_client_settings):
-    if (
-        table_client_settings is not None
-        and table_client_settings._native_json_in_result_sets
-    ):
+    if table_client_settings is not None and table_client_settings._native_json_in_result_sets:
         return json.loads(x)
-    if _from_bytes is not None:
-        return _from_bytes(x, table_client_settings)
     return x
 
 
@@ -59,10 +48,7 @@ def _from_uuid(pb, value):
 
 
 def _from_interval(value_pb, table_client_settings):
-    if (
-        table_client_settings is not None
-        and table_client_settings._native_interval_in_result_sets
-    ):
+    if table_client_settings is not None and table_client_settings._native_interval_in_result_sets:
         return timedelta(microseconds=value_pb.int64_value)
     return value_pb.int64_value
 
@@ -79,10 +65,7 @@ def _to_interval(pb, value):
 
 
 def _from_timestamp(value_pb, table_client_settings):
-    if (
-        table_client_settings is not None
-        and table_client_settings._native_timestamp_in_result_sets
-    ):
+    if table_client_settings is not None and table_client_settings._native_timestamp_in_result_sets:
         return _EPOCH + timedelta(microseconds=value_pb.uint64_value)
     return value_pb.uint64_value
 
@@ -114,7 +97,7 @@ class PrimitiveType(enum.Enum):
     Float = _apis.primitive_types.FLOAT, "float_value"
 
     String = _apis.primitive_types.STRING, "bytes_value"
-    Utf8 = _apis.primitive_types.UTF8, "text_value", _from_bytes
+    Utf8 = _apis.primitive_types.UTF8, "text_value"
 
     Yson = _apis.primitive_types.YSON, "bytes_value"
     Json = _apis.primitive_types.JSON, "text_value", _from_json
@@ -122,8 +105,9 @@ class PrimitiveType(enum.Enum):
     UUID = (_apis.primitive_types.UUID, None, _to_uuid, _from_uuid)
     Date = (
         _apis.primitive_types.DATE,
-        "uint32_value",
-        _from_date_number,
+        None,
+        _from_date,
+        _to_date,
     )
     Datetime = (
         _apis.primitive_types.DATETIME,
@@ -143,7 +127,7 @@ class PrimitiveType(enum.Enum):
         _to_interval,
     )
 
-    DyNumber = _apis.primitive_types.DYNUMBER, "text_value", _from_bytes
+    DyNumber = _apis.primitive_types.DYNUMBER, "text_value"
 
     def __init__(self, idn, proto_field, to_obj=None, from_obj=None):
         self._idn_ = idn
@@ -158,9 +142,7 @@ class PrimitiveType(enum.Enum):
         :return: A valid value of primitive type
         """
         if self._to_obj is not None and self._proto_field:
-            return self._to_obj(
-                getattr(value_pb, self._proto_field), table_client_settings
-            )
+            return self._to_obj(getattr(value_pb, self._proto_field), table_client_settings)
 
         if self._to_obj is not None:
             return self._to_obj(value_pb, table_client_settings)
@@ -231,9 +213,7 @@ class DecimalType(AbstractTypeBuilder):
         self._precision = precision
         self._scale = scale
         self._proto = _apis.ydb_value.Type()
-        self._proto.decimal_type.MergeFrom(
-            _apis.ydb_value.DecimalType(precision=self._precision, scale=self._scale)
-        )
+        self._proto.decimal_type.MergeFrom(_apis.ydb_value.DecimalType(precision=self._precision, scale=self._scale))
 
     @property
     def precision(self):
@@ -287,9 +267,7 @@ class OptionalType(AbstractTypeBuilder):
         self._repr = "%s?" % str(optional_type)
         self._proto = _apis.ydb_value.Type()
         self._item = optional_type
-        self._proto.optional_type.MergeFrom(
-            _apis.ydb_value.OptionalType(item=optional_type.proto)
-        )
+        self._proto.optional_type.MergeFrom(_apis.ydb_value.OptionalType(item=optional_type.proto))
 
     @property
     def item(self):
@@ -318,9 +296,7 @@ class ListType(AbstractTypeBuilder):
         :param list_type: List item type builder
         """
         self._repr = "List<%s>" % str(list_type)
-        self._proto = _apis.ydb_value.Type(
-            list_type=_apis.ydb_value.ListType(item=list_type.proto)
-        )
+        self._proto = _apis.ydb_value.Type(list_type=_apis.ydb_value.ListType(item=list_type.proto))
 
     @property
     def proto(self):
